---
name: Bug report
about: Create a report to help us improve
title: "[BUG]"
labels: ''
assignees: ''

---

**Describe the bug**
A clear and concise description of what the bug is.

**To Reproduce**
Steps to reproduce the behavior:
1. Go to '...'
2. Click on '....'
3. Scroll down to '....'
4. See error

**Expected behavior**
A clear and concise description of what you expected to happen.

**Environment (please complete the following information):**
 - OS: [e.g. iOS]
 - Version of Hybrid-Pool-Executor: [e.g. 0.1.0]
 - Version of Python: [e.g. CPython 3.10, Pypy 3.7]

**Additional context**
Add any other context about the problem here.
